==> witsml-clt-starter-1.2.4-sources.jar: digital/nedra/commons/starter/witsml/clt/config/WitsmlServerProperties.java <==
/*
 * Copyright 2023 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.witsml.clt.config;

import digital.nedra.commons.starter.witsml.clt.model.WitsmlVersion;
import java.net.URI;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import lombok.Getter;
import lombok.Setter;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.validation.annotation.Validated;

/**
 * Сгруппированные параметры подключения к WITSML серверу. Источником данных являются параметры
 * из application.yml c префиксом starters.witsml-clt.witsml-server.
 */
@Getter
@Setter
@Validated
@ConfigurationProperties(prefix = "starters.witsml-clt.witsml-server")
public class WitsmlServerProperties {
  /**
   * url Адрес WITSML сервера.
   */
  @NotNull
  URI url;
  /**
   * username Имя пользователя для подключения к WITSML серверу.
   */
  String username;
  /**
   * password Пароль для подключения к WITSML серверу.
   */
  String password;
  /**
   * version Версия WITSML.
   */
  @NotNull
  WitsmlVersion version;
  /**
   * authenticationType Тип аутентификации.
   */
  @NotBlank
  String authenticationType;
  /**
   * objectActiveIfGrowing Признак активности WITSML объекта определяется свойством
   *                              {@code objectGrowing}. Например, если значение {@code true}, то
   *                              активными будут считаться объекты с
   *                              {@code <objectGrowing>true</objectGrowing>}, если false - все
   *                              объекты являются активными.
   */
  boolean objectActiveIfGrowing;
  /**
   * path Путь для создания контроллера с POST запросом.
   */
  String path;
}

==> witsml-clt-starter-2.0.0-sources.jar: digital/nedra/commons/starter/witsml/clt/config/WitsmlServerProperties.java <==
/*
 * Copyright 2023 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.witsml.clt.config;

import digital.nedra.commons.starter.witsml.clt.model.WitsmlVersion;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import java.net.URI;
import lombok.Getter;
import lombok.Setter;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.validation.annotation.Validated;

/**
 * Сгруппированные параметры подключения к WITSML серверу. Источником данных являются параметры
 * из application.yml c префиксом starters.witsml-clt.witsml-server.
 */
@Getter
@Setter
@Validated
@ConfigurationProperties(prefix = "starters.witsml-clt.witsml-server")
public class WitsmlServerProperties {
  /**
   * url Адрес WITSML сервера.
   */
  @NotNull
  URI url;
  /**
   * username Имя пользователя для подключения к WITSML серверу.
   */
  String username;
  /**
   * password Пароль для подключения к WITSML серверу.
   */
  String password;
  /**
   * version Версия WITSML.
   */
  @NotNull
  WitsmlVersion version;
  /**
   * authenticationType Тип аутентификации.
   */
  @NotBlank
  String authenticationType;
  /**
   * path Путь для создания контроллера с POST запросом.
   */
  String path;
}
